@@ -62,7 +62,7 @@ def provision(state: State) -> int | bool:
         keys=["min_version", "minversion"],
         of_type=Version,
         # do not include local version specifier (because it's not allowed in version spec per PEP-440)
-        default=Version("4.0"),
+        default=None,  # type: ignore # Optional[Version] translates to object
         desc="Define the minimal tox version required to run",
     )
     state.conf.core.add_config(
@@ -72,10 +72,10 @@ def provision(state: State) -> int | bool:
         desc="Name of the virtual environment used to provision a tox.",
     )
 
-    def add_tox_requires_min_version(requires: list[Requirement]) -> list[Requirement]:
+    def add_tox_requires_min_version(reqs: list[Requirement]) -> list[Requirement]:
         min_version: Version = state.conf.core["min_version"]
-        requires.append(Requirement(f"tox >= {min_version}"))
-        return requires
+        reqs.append(Requirement(f"tox{f'>={min_version}' if min_version else ''}"))
+        return reqs
 
     state.conf.core.add_config(
         keys="requires",
@@ -97,7 +97,8 @@ def provision(state: State) -> int | bool:
         recreate=state.conf.options.recreate and not state.conf.options.no_recreate_provision,
     )
     provision_tox_env: str = state.conf.core["provision_tox_env"]
-    state.envs._mark_provision(bool(missing), provision_tox_env, loader)
+    state.conf.memory_seed_loaders[provision_tox_env].append(loader)
+    state.envs._mark_provision(bool(missing), provision_tox_env)
 
     from tox.plugin.manager import MANAGER
 
@@ -113,8 +114,9 @@ def provision(state: State) -> int | bool:
         msg = f"provisioning explicitly disabled within {sys.executable}, but {miss_msg}"
         if isinstance(no_provision, str):
             msg += f" and wrote to {no_provision}"
+            min_version = str(next(i.specifier for i in requires if i.name == "tox")).split("=")
             requires_dict = {
-                "minversion": str(next(i.specifier for i in requires if i.name == "tox")).split("=")[1],
+                "minversion": min_version[1] if len(min_version) >= 2 else None,
                 "requires": [str(i) for i in requires],
             }
             Path(no_provision).write_text(json.dumps(requires_dict, indent=4))
@@ -148,5 +150,5 @@ def run_provision(name: str, state: State) -> int:
         raise HandledError(f"cannot provision tox environment {tox_env.conf['env_name']} because {exception}")
     args: list[str] = [str(env_python), "-m", "tox"]
     args.extend(state.args)
-    outcome = tox_env.execute(cmd=args, stdin=StdinSource.user_only(), show=True, run_id="provision")
+    outcome = tox_env.execute(cmd=args, stdin=StdinSource.user_only(), show=True, run_id="provision", cwd=Path.cwd())
     return cast(int, outcome.exit_code)
