@@ -165,9 +165,10 @@ def env_run_create_flags(parser: ArgumentParser, mode: str) -> None:
         )
 
 
-def report(start: float, runs: list[ToxEnvRunResult], is_colored: bool) -> int:
+def report(start: float, runs: list[ToxEnvRunResult], is_colored: bool, verbosity: int) -> int:
     def _print(color_: int, message: str) -> None:
-        print(f"{color_ if is_colored else ''}{message}{Fore.RESET if is_colored else ''}")
+        if verbosity:
+            print(f"{color_ if is_colored else ''}{message}{Fore.RESET if is_colored else ''}")
 
     successful, skipped = [], []
     for run in runs:
@@ -186,7 +187,9 @@ def report(start: float, runs: list[ToxEnvRunResult], is_colored: bool) -> int:
         _print(Fore.GREEN, f"  congratulations :) ({duration:.2f} seconds)")
         return Outcome.OK
     _print(Fore.RED, f"  evaluation failed :( ({duration:.2f} seconds)")
-    return runs[0].code if len(runs) == 1 else -1
+    if len(runs) == 1:
+        return runs[0].code if not runs[0].skipped else -1
+    return -1
 
 
 def _get_outcome_message(run: ToxEnvRunResult) -> tuple[str, int]:
@@ -250,7 +253,12 @@ def execute(state: State, max_workers: int | None, has_spinner: bool, live: bool
         # write the journal
         write_journal(getattr(state.conf.options, "result_json", None), state._journal)
         # report the outcome
-        exit_code = report(state.conf.options.start, ordered_results, state.conf.options.is_colored)
+        exit_code = report(
+            state.conf.options.start,
+            ordered_results,
+            state.conf.options.is_colored,
+            state.conf.options.verbosity,
+        )
         if has_previous:
             signal(SIGINT, previous)
     return exit_code
@@ -293,7 +301,11 @@ def _queue_and_wait(
 
             def _run(tox_env: RunToxEnv) -> ToxEnvRunResult:
                 spinner.add(tox_env.conf.name)
-                return run_one(tox_env, options.parsed.no_test, suspend_display=live is False)
+                return run_one(
+                    tox_env,
+                    options.parsed.no_test or options.parsed.package_only,
+                    suspend_display=live is False,
+                )
 
             try:
                 executor = ThreadPoolExecutor(max_workers=max_workers, thread_name_prefix="tox-driver")
