@@ -1,7 +1,8 @@
 """Handles creating a release PR"""
+from __future__ import annotations
+
 from pathlib import Path
 from subprocess import check_call
-from typing import Tuple
 
 from git import Commit, Head, Remote, Repo, TagReference
 from packaging.version import Version
@@ -16,21 +17,28 @@ def main(version_str: str) -> None:
     if repo.is_dirty():
         raise RuntimeError("Current repository is dirty. Please commit any changes and try again.")
     upstream, release_branch = create_release_branch(repo, version)
-    release_commit = release_changelog(repo, version)
-    tag = tag_release_commit(release_commit, repo, version)
-    print("push release commit")
-    repo.git.push(upstream.name, release_branch)
-    print("push release tag")
-    repo.git.push(upstream.name, tag)
+    try:
+        release_commit = release_changelog(repo, version)
+        tag = tag_release_commit(release_commit, repo, version)
+        print("push release commit")
+        repo.git.push(upstream.name, f"{release_branch}:main", "-f")
+        print("push release tag")
+        repo.git.push(upstream.name, tag, "-f")
+    finally:
+        print("checkout main to new release and delete release branch")
+        repo.heads.main.checkout()
+        repo.delete_head(release_branch, force=True)
+        upstream.fetch()
+        repo.git.reset("--hard", "upstream/main")
     print("All done! ✨ 🍰 ✨")
 
 
-def create_release_branch(repo: Repo, version: Version) -> Tuple[Remote, Head]:
-    print("create release branch from upstream legacy")
+def create_release_branch(repo: Repo, version: Version) -> tuple[Remote, Head]:
+    print("create release branch from upstream main")
     upstream = get_upstream(repo)
     upstream.fetch()
     branch_name = f"release-{version}"
-    release_branch = repo.create_head(branch_name, upstream.refs.legacy, force=True)
+    release_branch = repo.create_head(branch_name, upstream.refs.main, force=True)
     upstream.push(refspec=f"{branch_name}:{branch_name}", force=True)
     release_branch.set_tracking_branch(repo.refs[f"{upstream.name}/{branch_name}"])
     release_branch.checkout()
@@ -39,9 +47,8 @@ def create_release_branch(repo: Repo, version: Version) -> Tuple[Remote, Head]:
 
 def get_upstream(repo: Repo) -> Remote:
     for remote in repo.remotes:
-        for url in remote.urls:
-            if url.endswith("tox-dev/tox.git"):
-                return remote
+        if any(url.endswith("tox-dev/tox.git") for url in remote.urls):
+            return remote
     raise RuntimeError("could not find tox-dev/tox.git remote")
 
 
