@@ -187,3 +187,49 @@ def test_provision_no_recreate_json(tox_project: ToxProjectCreator) -> None:
     with (project.path / "out.json").open() as file_handler:
         requires = json.load(file_handler)
     assert requires == {"minversion": None, "requires": ["p", "tox"]}
+
+
+@pytest.mark.integration()
+@pytest.mark.usefixtures("_pypi_index_self")
+@pytest.mark.parametrize("plugin_testenv", ["testenv", "testenv:a"])
+def test_provision_plugin_runner(tox_project: ToxProjectCreator, tmp_path: Path, plugin_testenv: str) -> None:
+    """Ensure that testenv runner doesn't affect the provision env."""
+    log = tmp_path / "out.log"
+    proj = tox_project(
+        {"tox.ini": f"[tox]\nrequires=demo-pkg-inline\nlabels=l=py\n[{plugin_testenv}]\nrunner=example"},
+    )
+    prov_msg = (
+        f"ROOT: will run in automatically provisioned tox, host {sys.executable} is missing"
+        f" [requires (has)]: demo-pkg-inline"
+    )
+
+    result_env = proj.run("r", "-e", "py", "--result-json", str(log))
+    result_env.assert_success()
+    assert prov_msg in result_env.out
+
+    result_label = proj.run("r", "-m", "l", "--result-json", str(log))
+    result_label.assert_success()
+    assert prov_msg in result_label.out
+
+
+@pytest.mark.integration()
+def test_provision_plugin_runner_in_provision(tox_project: ToxProjectCreator, tmp_path: Path) -> None:
+    """Ensure that provision environment can be explicitly configured."""
+    log = tmp_path / "out.log"
+    proj = tox_project({"tox.ini": "[tox]\nrequires=somepkg123xyz\n[testenv:.tox]\nrunner=example"})
+    with pytest.raises(KeyError, match="example"):
+        proj.run("r", "-e", "py", "--result-json", str(log))
+
+
+@pytest.mark.integration()
+@pytest.mark.usefixtures("_pypi_index_self")
+@pytest.mark.parametrize("relative_path", [True, False], ids=["relative", "absolute"])
+def test_provision_conf_file(tox_project: ToxProjectCreator, tmp_path: Path, relative_path: bool) -> None:
+    ini = "[tox]\nrequires = demo-pkg-inline\nskipsdist=true\n"
+    project = tox_project({"tox.ini": ini}, prj_path=tmp_path / "sub")
+    if relative_path:
+        conf_path = os.path.join(project.path.name, "tox.ini")
+    else:
+        conf_path = str(project.path / "tox.ini")
+    result = project.run("c", "--conf", conf_path, "-e", "py", from_cwd=tmp_path)
+    result.assert_success()
